@@ -60,78 +60,78 @@ test_that("correct data is used", {
 
 test_that("layer parameters are correct", {
   expect_is(p$layers[[1]], "ggproto")
-  expect_equal(deparse(p$layers[[1]]$mapping$x), "~x")
-  expect_equal(deparse(p$layers[[1]]$mapping$y), "~y")
-  expect_equal(deparse(p$layers[[1]]$mapping$group), "~group")
+  expect_equal(deparse(p$layers[[1]]$mapping$x), "~.data$x")
+  expect_equal(deparse(p$layers[[1]]$mapping$y), "~.data$y")
+  expect_equal(deparse(p$layers[[1]]$mapping$group), "~.data$group")
   expect_equal(as.character(p$layers[[1]]$aes_params$colour), "black")
   expect_equal(as.character(p$layers[[1]]$aes_params$fill), "red")
   expect_equal(p$layers[[1]]$aes_params$linewidth, 0.4)
 
   expect_is(q$layers[[1]], "ggproto")
-  expect_equal(deparse(q$layers[[1]]$mapping$x), "~.data[[\"x\"]]")
-  expect_equal(deparse(q$layers[[1]]$mapping$y), "~.data[[\"y\"]]")
-  expect_equal(deparse(q$layers[[1]]$mapping$group), "~.data[[\"group\"]]")
+  expect_equal(deparse(q$layers[[1]]$mapping$x), "~.data$x")
+  expect_equal(deparse(q$layers[[1]]$mapping$y), "~.data$y")
+  expect_equal(deparse(q$layers[[1]]$mapping$group), "~.data$group")
   expect_equal(deparse(q$layers[[1]]$mapping$fill), "~.data[[\"pop_2015\"]]")
   expect_equal(as.character(q$layers[[1]]$aes_params$colour), "blue")
   expect_equal(q$layers[[1]]$aes_params$linewidth, 0.4)
 
   expect_is(r$layers[[1]], "ggproto")
-  expect_equal(deparse(r$layers[[1]]$mapping$x), "~.data[[\"x\"]]")
-  expect_equal(deparse(r$layers[[1]]$mapping$y), "~.data[[\"y\"]]")
-  expect_equal(deparse(r$layers[[1]]$mapping$group), "~.data[[\"group\"]]")
+  expect_equal(deparse(r$layers[[1]]$mapping$x), "~.data$x")
+  expect_equal(deparse(r$layers[[1]]$mapping$y), "~.data$y")
+  expect_equal(deparse(r$layers[[1]]$mapping$group), "~.data$group")
   expect_equal(deparse(r$layers[[1]]$mapping$fill), "~.data[[\"values\"]]")
   expect_equal(as.character(r$layers[[1]]$aes_params$colour), "black")
   expect_equal(r$layers[[1]]$aes_params$linewidth, 0.8)
 
   expect_is(s$layers[[1]], "ggproto")
-  expect_equal(deparse(s$layers[[1]]$mapping$x), "~x")
-  expect_equal(deparse(s$layers[[1]]$mapping$y), "~y")
-  expect_equal(deparse(s$layers[[1]]$mapping$group), "~group")
+  expect_equal(deparse(s$layers[[1]]$mapping$x), "~.data$x")
+  expect_equal(deparse(s$layers[[1]]$mapping$y), "~.data$y")
+  expect_equal(deparse(s$layers[[1]]$mapping$group), "~.data$group")
   expect_equal(as.character(s$layers[[1]]$aes_params$fill), "white")
   expect_equal(as.character(s$layers[[1]]$aes_params$colour), "black")
   expect_equal(s$layers[[1]]$aes_params$linewidth, 0.4)
   expect_is(s$layers[[2]], "ggproto")
-  expect_equal(deparse(s$layers[[2]]$mapping$x), "~x")
-  expect_equal(deparse(s$layers[[2]]$mapping$y), "~y")
-  expect_equal(deparse(s$layers[[2]]$mapping$label), "~abbr")
+  expect_equal(deparse(s$layers[[2]]$mapping$x), "~.data$x")
+  expect_equal(deparse(s$layers[[2]]$mapping$y), "~.data$y")
+  expect_equal(deparse(s$layers[[2]]$mapping$label), "~.data$abbr")
   expect_equal(as.character(s$layers[[2]]$aes_params$colour), "blue")
 
   expect_is(t$layers[[1]], "ggproto")
-  expect_equal(deparse(t$layers[[1]]$mapping$x), "~x")
-  expect_equal(deparse(t$layers[[1]]$mapping$y), "~y")
-  expect_equal(deparse(t$layers[[1]]$mapping$group), "~group")
+  expect_equal(deparse(t$layers[[1]]$mapping$x), "~.data$x")
+  expect_equal(deparse(t$layers[[1]]$mapping$y), "~.data$y")
+  expect_equal(deparse(t$layers[[1]]$mapping$group), "~.data$group")
   expect_equal(as.character(t$layers[[1]]$aes_params$fill), "yellow")
   expect_equal(as.character(t$layers[[1]]$aes_params$colour), "black")
   expect_equal(t$layers[[1]]$aes_params$linewidth, 0.6)
   expect_is(t$layers[[2]], "ggproto")
-  expect_equal(deparse(t$layers[[2]]$mapping$x), "~x")
-  expect_equal(deparse(t$layers[[2]]$mapping$y), "~y")
+  expect_equal(deparse(t$layers[[2]]$mapping$x), "~.data$x")
+  expect_equal(deparse(t$layers[[2]]$mapping$y), "~.data$y")
   expect_equal(deparse(t$layers[[2]]$mapping$label),
-               "~sub(\" County\", \"\", county)")
+               "~sub(\" County\", \"\", .data$county)")
 
   expect_is(u$layers[[1]], "ggproto")
-  expect_equal(deparse(u$layers[[1]]$mapping$x), "~x")
-  expect_equal(deparse(u$layers[[1]]$mapping$y), "~y")
-  expect_equal(deparse(u$layers[[1]]$mapping$group), "~group")
+  expect_equal(deparse(u$layers[[1]]$mapping$x), "~.data$x")
+  expect_equal(deparse(u$layers[[1]]$mapping$y), "~.data$y")
+  expect_equal(deparse(u$layers[[1]]$mapping$group), "~.data$group")
   expect_equal(as.character(u$layers[[1]]$aes_params$fill), "white")
   expect_equal(as.character(u$layers[[1]]$aes_params$colour), "black")
   expect_equal(u$layers[[1]]$aes_params$linewidth, 0.4)
   expect_is(u$layers[[2]], "ggproto")
-  expect_equal(deparse(u$layers[[2]]$mapping$x), "~x")
-  expect_equal(deparse(u$layers[[2]]$mapping$y), "~y")
-  expect_equal(deparse(u$layers[[2]]$mapping$label), "~abbr")
+  expect_equal(deparse(u$layers[[2]]$mapping$x), "~.data$x")
+  expect_equal(deparse(u$layers[[2]]$mapping$y), "~.data$y")
+  expect_equal(deparse(u$layers[[2]]$mapping$label), "~.data$abbr")
 
   expect_is(v$layers[[1]], "ggproto")
-  expect_equal(deparse(v$layers[[1]]$mapping$x), "~x")
-  expect_equal(deparse(v$layers[[1]]$mapping$y), "~y")
-  expect_equal(deparse(v$layers[[1]]$mapping$group), "~group")
+  expect_equal(deparse(v$layers[[1]]$mapping$x), "~.data$x")
+  expect_equal(deparse(v$layers[[1]]$mapping$y), "~.data$y")
+  expect_equal(deparse(v$layers[[1]]$mapping$group), "~.data$group")
   expect_equal(as.character(v$layers[[1]]$aes_params$fill), "white")
   expect_equal(as.character(v$layers[[1]]$aes_params$colour), "black")
   expect_equal(v$layers[[1]]$aes_params$linewidth, 0.4)
   expect_is(v$layers[[2]], "ggproto")
-  expect_equal(deparse(v$layers[[2]]$mapping$x), "~x")
-  expect_equal(deparse(v$layers[[2]]$mapping$y), "~y")
-  expect_equal(deparse(v$layers[[2]]$mapping$label), "~abbr")
+  expect_equal(deparse(v$layers[[2]]$mapping$x), "~.data$x")
+  expect_equal(deparse(v$layers[[2]]$mapping$y), "~.data$y")
+  expect_equal(deparse(v$layers[[2]]$mapping$label), "~.data$abbr")
 })
 
 test_that("warning occurs for unnecessary fill argument", {
